pub trait ExecuteMsgFns<Chain: TxHandler, CwOrchExecuteMsgType>: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>where
ExecuteMsg: Into<CwOrchExecuteMsgType>,{
// Provided methods
fn ibc_query(
&self,
callback: CallbackRequest,
msgs: Vec<QueryRequest<Empty>>,
timeout_seconds: impl Into<Uint64>,
) -> Result<TxResponse<Chain>, CwEnvError> { ... }
fn ibc_execute(
&self,
msgs: Vec<CosmosMsg<Empty>>,
timeout_seconds: impl Into<Uint64>,
callback: Option<CallbackRequest>,
) -> Result<TxResponse<Chain>, CwEnvError> { ... }
}Expand description
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.
Provided Methods
Sourcefn ibc_query(
&self,
callback: CallbackRequest,
msgs: Vec<QueryRequest<Empty>>,
timeout_seconds: impl Into<Uint64>,
) -> Result<TxResponse<Chain>, CwEnvError>
fn ibc_query( &self, callback: CallbackRequest, msgs: Vec<QueryRequest<Empty>>, timeout_seconds: impl Into<Uint64>, ) -> Result<TxResponse<Chain>, CwEnvError>
Automatically generated wrapper around ExecuteMsg::Query variant
Sourcefn ibc_execute(
&self,
msgs: Vec<CosmosMsg<Empty>>,
timeout_seconds: impl Into<Uint64>,
callback: Option<CallbackRequest>,
) -> Result<TxResponse<Chain>, CwEnvError>
fn ibc_execute( &self, msgs: Vec<CosmosMsg<Empty>>, timeout_seconds: impl Into<Uint64>, callback: Option<CallbackRequest>, ) -> Result<TxResponse<Chain>, CwEnvError>
Automatically generated wrapper around ExecuteMsg::Execute variant
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl<Chain: TxHandler, CwOrchExecuteMsgType, SupportedContract> ExecuteMsgFns<Chain, CwOrchExecuteMsgType> for SupportedContractwhere
ExecuteMsg: Into<CwOrchExecuteMsgType>,
SupportedContract: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>,
Available on non-WebAssembly only.