pub trait QueryMsgFns<Chain: QueryHandler + ChainState, CwOrchQueryMsgType>: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>{
// Provided methods
fn active_channel(&self) -> Result<Option<String>, CwEnvError> { ... }
fn pair(&self) -> Result<Option<Pair>, CwEnvError> { ... }
fn remote_address(
&self,
local_address: impl Into<String>,
) -> Result<Option<String>, CwEnvError> { ... }
fn block_max_gas(&self) -> Result<Uint64, CwEnvError> { ... }
}Expand description
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.
Provided Methods
Sourcefn active_channel(&self) -> Result<Option<String>, CwEnvError>
fn active_channel(&self) -> Result<Option<String>, CwEnvError>
Automatically generated wrapper around QueryMsg::ActiveChannel variant
Sourcefn pair(&self) -> Result<Option<Pair>, CwEnvError>
fn pair(&self) -> Result<Option<Pair>, CwEnvError>
Automatically generated wrapper around QueryMsg::Pair variant
Sourcefn remote_address(
&self,
local_address: impl Into<String>,
) -> Result<Option<String>, CwEnvError>
fn remote_address( &self, local_address: impl Into<String>, ) -> Result<Option<String>, CwEnvError>
Automatically generated wrapper around QueryMsg::RemoteAddress variant
Sourcefn block_max_gas(&self) -> Result<Uint64, CwEnvError>
fn block_max_gas(&self) -> Result<Uint64, CwEnvError>
Automatically generated wrapper around QueryMsg::BlockMaxGas variant
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl<Chain: QueryHandler + ChainState, CwOrchQueryMsgType, SupportedContract> QueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContractwhere
QueryMsg: Into<CwOrchQueryMsgType>,
SupportedContract: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,
Available on non-WebAssembly only.