Module msg
Source - InstantiateMsg
- Pair
- This contract’s voice. There is one voice per note, and many notes
per voice.
- ExecuteMsg
- MigrateMsg
- QueryMsg
- AsyncQueryMsgFns
- Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.
- ExecuteMsgFns
- Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.
- QueryMsgFns
- Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.